==> alfresco-repository-23.3.21.1-sources.jar: org/alfresco/repo/security/permissions/PermissionCheckValue.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.permissions;

import org.alfresco.service.cmr.repository.NodeRef;

/**
 * Interface for objects that can provide information to allow permission checks
 * <p/>
 * Implement this interface to enable the permission filtering layers to extract
 * information in order to check permissions.
 * 
 * @author Derek Hulley
 * @since 4.0
 */
public interface PermissionCheckValue
{
    /**
     * Get the underlying node value that needs to be permission checked.
     * 
     * @return              the underlying value to filter
     */
    NodeRef getNodeRef();
}

==> alfresco-repository-25.3.0.68-sources.jar: org/alfresco/repo/security/permissions/PermissionCheckValue.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.permissions;

import org.alfresco.service.cmr.repository.NodeRef;

/**
 * Interface for objects that can provide information to allow permission checks
 * <p/>
 * Implement this interface to enable the permission filtering layers to extract information in order to check permissions.
 * 
 * @author Derek Hulley
 * @since 4.0
 */
public interface PermissionCheckValue
{
    /**
     * Get the underlying node value that needs to be permission checked.
     * 
     * @return the underlying value to filter
     */
    NodeRef getNodeRef();
}
